import React from "react";
import PropTypes from "prop-types";
import { useDispatch } from "react-redux";

import { prettySize, prettyEpisodeName } from "../../../utils";
import { removeTorrent } from "../../../actions/torrents";

export const Torrent = ({ torrent }) => {
  const dispatch = useDispatch();

  var progressStyle = torrent.status.is_finished
    ? "success"
    : "info progress-bar-striped progress-bar-animated";
  const progressBarClass = "progress-bar bg-" + progressStyle;

  var percentDone = torrent.status.percent_done;
  const started = percentDone !== 0;
  if (started) {
    percentDone = Number(percentDone).toFixed(1) + "%";
  }

  const torrentTitle = (torrent) => {
    switch (torrent.type) {
      case "movie":
        return torrent.video ? torrent.video.title : torrent.status.name;
      case "episode":
        return torrent.video
          ? prettyEpisodeName(
              torrent.video.show_title,
              torrent.video.season,
              torrent.video.episode
            )
          : torrent.status.name;
      default:
        return torrent.status.name;
    }
  };

  // Pretty sizes
  const downloadedSize = prettySize(torrent.status.downloaded_size);
  const totalSize = prettySize(torrent.status.total_size);
  const downloadRate = prettySize(torrent.status.download_rate) + "/s";
  return (
    <div className="card w-100 mb-3">
      <h5 className="card-header">
        <span className="text text-break">{torrentTitle(torrent)}</span>
        <span
          className="fa fa-trash clickable pull-right"
          onClick={() => dispatch(removeTorrent(torrent.status.id))}
        ></span>
      </h5>
      <div className="card-body pb-0">
        {started && (
          <React.Fragment>
            <div className="progress bg-light">
              <div
                className={progressBarClass}
                style={{ width: percentDone }}
                role="progressbar"
                aria-valuenow={percentDone}
                aria-valuemin="0"
                aria-valuemax="100"
              ></div>
            </div>
            <p>
              {downloadedSize} / {totalSize} - {percentDone} - {downloadRate}
            </p>
          </React.Fragment>
        )}
        {!started && <p>Download not yet started</p>}
      </div>
    </div>
  );
};
Torrent.propTypes = {
  torrent: PropTypes.object.isRequired,
};
